@@ -39,19 +39,12 @@
 #include <QRandomGenerator>
 #include <QDialogButtonBox>
 
-#if QT_VERSION_MAJOR == 6
 #include <QNetworkInformation>
-#else
-#include <QNetworkConfigurationManager>
-#endif
 
 using namespace Knights;
 
 GameDialog::GameDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f),
 	ui(new Ui::GameDialog()),
-#if QT_VERSION_MAJOR == 5
-	m_networkManager(new QNetworkConfigurationManager(this)),
-#endif
 	okButton(nullptr) {
 
 	QFrame* mainFrame = new QFrame(this);
@@ -119,14 +112,14 @@ GameDialog::GameDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f),
 	connect(ui->rbPlayer1Human, &QRadioButton::clicked, this, &GameDialog::player1SettingsChanged);
 	connect(ui->rbPlayer1Engine, &QRadioButton::clicked, this, &GameDialog::player1SettingsChanged);
 	connect(ui->pbPlayer1Engine, &QPushButton::clicked, this, &GameDialog::showEngineConfigDialog);
-	connect(ui->cbPlayer1Engine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &GameDialog::checkOkButton);
+	connect(ui->cbPlayer1Engine, &QComboBox::currentIndexChanged, this, &GameDialog::checkOkButton);
 
 	//player 2
 	connect(ui->rbPlayer2Human, &QRadioButton::clicked, this, &GameDialog::player2SettingsChanged);
 	connect(ui->rbPlayer2Engine, &QRadioButton::clicked, this, &GameDialog::player2SettingsChanged);
 	connect(ui->rbPlayer2Server, &QRadioButton::clicked, this, &GameDialog::player2SettingsChanged);
 	connect(ui->pbPlayer2Engine, &QPushButton::clicked, this, &GameDialog::showEngineConfigDialog);
-	connect(ui->cbPlayer2Engine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &GameDialog::checkOkButton);
+	connect(ui->cbPlayer2Engine, &QComboBox::currentIndexChanged, this, &GameDialog::checkOkButton);
 
 	//time control
 	connect(ui->cbTimeControl, &QCheckBox::toggled, this, &GameDialog::timeControlChanged);
@@ -134,7 +127,6 @@ GameDialog::GameDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f),
 	connect(ui->sbTimeIncrement, static_cast<void (QSpinBox::*)(int)> (&QSpinBox::valueChanged), this, &GameDialog::updateTimeEdits);
 	connect(ui->sbNumberOfMoves, static_cast<void (QSpinBox::*)(int)> (&QSpinBox::valueChanged), this, &GameDialog::updateTimeEdits);
 
-#if QT_VERSION_MAJOR == 6
 	bool hasNetworkInfo = QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
 
 	if (hasNetworkInfo) {
@@ -144,11 +136,6 @@ GameDialog::GameDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f),
 
 		networkStatusChanged(QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online);
 	}
-#else
-	connect(m_networkManager, &QNetworkConfigurationManager::onlineStateChanged, this, &GameDialog::networkStatusChanged);
-
-	networkStatusChanged(m_networkManager->isOnline());
-#endif
 
 	updateTimeEdits();
 	player1SettingsChanged();
