@@ -36,11 +36,9 @@
 #include "enginesettings.h"
 
 // KDEGames
-#include <kdegames_version.h>
-#include <KgThemeSelector>
-#include <KStandardGameAction>
+#include <KGameThemeSelector>
+#include <KGameStandardAction>
 
-#include <kwidgetsaddons_version.h>
 #include <KConfigDialog>
 #include <KActionCollection>
 #include <KStandardAction>
@@ -68,7 +66,7 @@ using namespace Knights;
 */
 MainWindow::MainWindow() : KXmlGuiWindow(),
 	m_view(new KnightsView(this)),
-	m_themeProvider(new KgThemeProvider("Theme", this)) {
+	m_themeProvider(new KGameThemeProvider("Theme", this)) {
 	// accept dnd
 	setAcceptDrops(true);
 
@@ -84,18 +82,20 @@ MainWindow::MainWindow() : KXmlGuiWindow(),
 	setupGUI();
 
 	//protocol features
-	m_protocolFeatures [ KStandardGameAction::name(KStandardGameAction::Pause) ] = Protocol::Pause;
-	m_protocolFeatures [ "propose_draw" ] = Protocol::Draw;
-	m_protocolFeatures [ "adjourn" ] = Protocol::Adjourn;
-	m_protocolFeatures [ "resign" ] = Protocol::Resign;
-	m_protocolFeatures [ "abort" ] = Protocol::Abort;
+	m_protocolFeatures = {
+	    {KGameStandardAction::name(KGameStandardAction::Pause), Protocol::Pause},
+	    {QStringLiteral("propose_draw"), Protocol::Draw},
+	    {QStringLiteral("adjourn"), Protocol::Adjourn},
+	    {QStringLiteral("resign"), Protocol::Resign},
+	    {QStringLiteral("abort"), Protocol::Abort},
+	};
 
 	// setup difficulty management
-	connect(Kg::difficulty(), &KgDifficulty::currentLevelChanged, Manager::self(), &Manager::levelChanged);
-	Kg::difficulty()->addLevel(new KgDifficultyLevel(0, "custom", i18n("Custom"), false));
-	Kg::difficulty()->addStandardLevelRange(KgDifficultyLevel::VeryEasy, KgDifficultyLevel::VeryHard, KgDifficultyLevel::Medium);
-	KgDifficultyGUI::init(this);
-	Kg::difficulty()->setEditable(false);
+	connect(KGameDifficulty::global(), &KGameDifficulty::currentLevelChanged, Manager::self(), &Manager::levelChanged);
+	KGameDifficulty::global()->addLevel(new KGameDifficultyLevel(0, "custom", i18n("Custom"), false));
+	KGameDifficulty::global()->addStandardLevelRange(KGameDifficultyLevel::VeryEasy, KGameDifficultyLevel::VeryHard, KGameDifficultyLevel::Medium);
+	KGameDifficultyGUI::init(this);
+	KGameDifficulty::global()->setEditable(false);
 
 	// make all the docks invisible.
 	// Show required docks after the game protocols are selected
@@ -112,11 +112,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(),
 	connect(Manager::self(), &Manager::winnerNotify, this, &MainWindow::gameOver);
 	connect(qApp, &QGuiApplication::lastWindowClosed, this, &MainWindow::exitKnights);
 
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
 	m_themeProvider->discoverThemes(QStringLiteral("themes"));
-#else
-	m_themeProvider->discoverThemes("appdata", QStringLiteral("themes"));
-#endif
 	m_view->drawBoard(m_themeProvider);
 }
 
@@ -180,32 +176,32 @@ void MainWindow::setupDocks() {
 }
 
 void MainWindow::setupActions() {
-	KStandardGameAction::gameNew(this, SLOT(fileNew()), actionCollection());
-	KStandardGameAction::quit(qApp, SLOT(closeAllWindows()), actionCollection());
-	m_pauseAction = KStandardGameAction::pause(Manager::self(), SLOT(pause(bool)), actionCollection());
+	KGameStandardAction::gameNew(this, &MainWindow::fileNew, actionCollection());
+	KGameStandardAction::quit(qApp, &QApplication::closeAllWindows, actionCollection());
+	m_pauseAction = KGameStandardAction::pause(Manager::self(), &Manager::pause, actionCollection());
 	m_pauseAction->setEnabled(false);
-	KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
+	KStandardAction::preferences(this, &MainWindow::optionsPreferences, actionCollection());
 
-	m_saveAction = KStandardGameAction::save(this, SLOT(fileSave()), actionCollection());
+	m_saveAction = KGameStandardAction::save(this, &MainWindow::fileSave, actionCollection());
 	m_saveAction->setEnabled(false);
-	m_saveAsAction = KStandardGameAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
+	m_saveAsAction = KGameStandardAction::saveAs(this, &MainWindow::fileSaveAs, actionCollection());
 	m_saveAsAction->setEnabled(false);
-	KStandardGameAction::load(this, SLOT(fileLoad()), actionCollection());
+	KGameStandardAction::load(this, &MainWindow::fileLoad, actionCollection());
 
-	m_resignAction = actionCollection()->addAction(QStringLiteral("resign"), this, SLOT(resign()));
+	m_resignAction = actionCollection()->addAction(QStringLiteral("resign"), this, &MainWindow::resign);
 	m_resignAction->setText(i18n("Resign"));
 	m_resignAction->setToolTip(i18n("Admit your inevitable defeat"));
 	m_resignAction->setIcon(QIcon::fromTheme(QStringLiteral("flag-red")));
 	m_resignAction->setEnabled(false);
 
-	m_undoAction = actionCollection()->addAction(QStringLiteral("move_undo"), this, SLOT(undo()));
+	m_undoAction = actionCollection()->addAction(QStringLiteral("move_undo"), this, &MainWindow::undo);
 	m_undoAction->setText(i18n("Undo"));
 	m_undoAction->setToolTip(i18n("Take back your last move"));
 	m_undoAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
 	connect(Manager::self(), &Manager::undoPossible, m_undoAction, &QAction::setEnabled);
 	m_undoAction->setEnabled(false);
 
-	m_redoAction = actionCollection()->addAction(QStringLiteral("move_redo"), this, SLOT(redo()));
+	m_redoAction = actionCollection()->addAction(QStringLiteral("move_redo"), this, &MainWindow::redo);
 	m_redoAction->setText(i18n("Redo"));
 	m_redoAction->setToolTip(i18n("Repeat your last move"));
 	m_redoAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-redo")));
@@ -213,19 +209,19 @@ void MainWindow::setupActions() {
 	m_redoAction->setEnabled(false);
 	m_redoAction->setVisible(false);
 
-	m_drawAction = actionCollection()->addAction(QStringLiteral("propose_draw"), Manager::self(), SLOT(offerDraw()));
+	m_drawAction = actionCollection()->addAction(QStringLiteral("propose_draw"), Manager::self(), &Manager::offerDraw);
 	m_drawAction->setText(i18n("Offer &Draw"));
 	m_drawAction->setToolTip(i18n("Offer a draw to your opponent"));
 	m_drawAction->setIcon(QIcon::fromTheme(QStringLiteral("flag-blue")));
 	m_drawAction->setEnabled(false);
 
-	m_adjournAction = actionCollection()->addAction(QStringLiteral("adjourn"), Manager::self(), SLOT(adjourn()));
+	m_adjournAction = actionCollection()->addAction(QStringLiteral("adjourn"), Manager::self(), &Manager::adjourn);
 	m_adjournAction->setText(i18n("Adjourn"));
 	m_adjournAction->setToolTip(i18n("Continue this game at a later time"));
 	m_adjournAction->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
 	m_adjournAction->setEnabled(false);
 
-	QAction* abortAction = actionCollection()->addAction(QStringLiteral("abort"), Manager::self(), SLOT(abort()));
+	QAction* abortAction = actionCollection()->addAction(QStringLiteral("abort"), Manager::self(), &Manager::abort);
 	abortAction->setText(i18n("Abort"));
 	abortAction->setToolTip(i18n("End the game immediately"));
 	abortAction->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
@@ -280,7 +276,7 @@ void MainWindow::fileNew() {
 
 		bool difficulty = (Protocol::white()->supportedFeatures()& Protocol::AdjustDifficulty)
 		                  || (Protocol::black()->supportedFeatures()& Protocol::AdjustDifficulty);
-		Kg::difficulty()->setEditable(difficulty);
+		KGameDifficulty::global()->setEditable(difficulty);
 	}
 	delete gameNewDialog;
 
@@ -293,7 +289,7 @@ void MainWindow::fileLoad() {
 	if(!maybeSave())
 		return;
 
-	KConfigGroup conf(KSharedConfig::openConfig(), "MainWindow");
+	KConfigGroup conf(KSharedConfig::openConfig(), QStringLiteral("MainWindow"));
 	QString dir = conf.readEntry("LastOpenDir", "");
 	const QString&  fileName = QFileDialog::getOpenFileName(this, i18n("Open File"), dir,
 	                           i18n("Portable game notation (*.pgn)"));
@@ -364,9 +360,8 @@ void MainWindow::protocolInitSuccesful() {
 		f &= Protocol::black()->supportedFeatures();
 	}
 
-	QMap<QByteArray, Protocol::Feature>::ConstIterator it;
-	for(it = m_protocolFeatures.constBegin(); it != m_protocolFeatures.constEnd(); ++it)
-		actionCollection()->action(QLatin1String(it.key()))->setEnabled(f & it.value());
+	for (auto it = m_protocolFeatures.constBegin(); it != m_protocolFeatures.constEnd(); ++it)
+		actionCollection()->action(it.key())->setEnabled(f & it.value());
 
 	// show console action button if protocol allows a console
 	// show console dock widget if protocol allows and configuration file entry has visible = true
@@ -377,7 +372,7 @@ void MainWindow::protocolInitSuccesful() {
 	QList<Protocol::ToolWidgetData> list;
 	list << Protocol::black()->toolWidgets();
 	list << Protocol::white()->toolWidgets();
-	for (const auto& data : qAsConst(list)) {
+	for (const auto& data : std::as_const(list)) {
 		switch(data.type) {
 		case Protocol::ConsoleToolWidget:
 			if(data.owner == White) {
@@ -473,7 +468,7 @@ void MainWindow::optionsPreferences() {
 // 	ui_prefs_access.setupUi(accessDlg);
 // 	dialog->addPage(accessDlg, i18n("Accessibility"), QLatin1String("preferences-desktop-accessibility"));
 
-    KgThemeSelector* themeDlg = new KgThemeSelector(m_themeProvider, KgThemeSelector::EnableNewStuffDownload, dialog);
+    KGameThemeSelector* themeDlg = new KGameThemeSelector(m_themeProvider, KGameThemeSelector::EnableNewStuffDownload, dialog);
     themeDlg->setNewStuffConfigFileName(QStringLiteral("knights.knsrc"));
 	dialog->addPage(themeDlg, i18n("Theme"), QStringLiteral("games-config-theme"));
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
@@ -482,26 +477,18 @@ void MainWindow::optionsPreferences() {
 }
 
 void MainWindow::resign() {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 	int rc = KMessageBox::questionTwoActions(this,
-#else
-	int rc = KMessageBox::questionYesNo(this,
-#endif
 					    i18n("Do you really want to resign?"), i18n("Resign"),
 					    KGuiItem(i18nc("@action:button", "Resign"), QStringLiteral("flag-red")),
 					    KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 	if (rc == KMessageBox::PrimaryAction)
-#else
-	if (rc == KMessageBox::Yes)
-#endif
 		Manager::self()->resign();
 }
 
 void MainWindow::undo() {
 	if(!Protocol::white()->isLocal() && !Protocol::black()->isLocal()) {
 		// No need to pause the game if both players are local
-		QAction* pa = actionCollection()->action(QLatin1String(KStandardGameAction::name(KStandardGameAction::Pause)));
+		QAction* pa = actionCollection()->action(KGameStandardAction::name(KGameStandardAction::Pause));
 		if(pa)
 			pa->setChecked(true);
 	}
@@ -512,7 +499,7 @@ void MainWindow::redo() {
 	Manager::self()->redo();
 	if(!Protocol::white()->isLocal() && !Protocol::black()->isLocal()) {
 		// No need to pause the game if both players are local
-		QAction* pa = actionCollection()->action(QLatin1String(KStandardGameAction::name(KStandardGameAction::Pause)));
+		QAction* pa = actionCollection()->action(KGameStandardAction::name(KGameStandardAction::Pause));
 		if(pa && !Manager::self()->canRedo())
 			pa->setChecked(false);
 	}
@@ -543,12 +530,12 @@ void MainWindow::gameOver(Color winner) {
 	mainLayout->addWidget(mainWidget);
 
 	QDialogButtonBox *bBox = new QDialogButtonBox( QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Apply );
-	QMap<QDialogButtonBox::StandardButton, QByteArray> buttonsMap;
-	buttonsMap[QDialogButtonBox::Ok] = KStandardGameAction::name ( KStandardGameAction::New );
-	buttonsMap[QDialogButtonBox::Apply] = KStandardGameAction::name ( KStandardGameAction::Save );
+	QMap<QDialogButtonBox::StandardButton, QString> buttonsMap;
+	buttonsMap[QDialogButtonBox::Ok] = KGameStandardAction::name ( KGameStandardAction::New );
+	buttonsMap[QDialogButtonBox::Apply] = KGameStandardAction::name ( KGameStandardAction::Save );
 
-	for ( QMap<QDialogButtonBox::StandardButton, QByteArray>::ConstIterator it = buttonsMap.constBegin(); it != buttonsMap.constEnd(); ++it ) {
-		QAction* a = actionCollection()->action ( QLatin1String ( it.value() ) );
+	for ( auto it = buttonsMap.constBegin(); it != buttonsMap.constEnd(); ++it ) {
+		QAction* a = actionCollection()->action ( it.value() );
 		Q_ASSERT(a);
 
 		bBox->button ( it.key() )->setText ( a->text() );
@@ -638,11 +625,7 @@ bool MainWindow::maybeSave() {
 
 	Settings::setDontAskInternal(QString());
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 	int result = KMessageBox::warningTwoActionsCancel(QApplication::activeWindow(),
-#else
-	int result = KMessageBox::warningYesNoCancel(QApplication::activeWindow(),
-#endif
 	             i18n("This will end your game.\nWould you like to save the move history?"),
 	             QString(),
 	             KStandardGuiItem::save(),
@@ -651,17 +634,9 @@ bool MainWindow::maybeSave() {
 	             QLatin1String(DontAskDiscard));
 
 	KMessageBox::ButtonCode res;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 	Settings::setAskDiscard(KMessageBox::shouldBeShownTwoActions(QLatin1String(DontAskDiscard), res));
-#else
-	Settings::setAskDiscard(KMessageBox::shouldBeShownYesNo(QLatin1String(DontAskDiscard), res));
-#endif
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 	if(result == KMessageBox::PrimaryAction)
-#else
-	if(result == KMessageBox::Yes)
-#endif
 		fileSave();
 
 	return result != KMessageBox::Cancel;
@@ -669,7 +644,7 @@ bool MainWindow::maybeSave() {
 
 void MainWindow::fileSave() {
 	if(m_fileName.isEmpty()) {
-		KConfigGroup conf(KSharedConfig::openConfig(), "MainWindow");
+		KConfigGroup conf(KSharedConfig::openConfig(), QStringLiteral("MainWindow"));
 		QString dir = conf.readEntry("LastOpenDir", "");
 		m_fileName = QFileDialog::getSaveFileName(this, i18n("Save"), dir,
 		             i18n("Portable game notation (*.pgn)"));
@@ -692,7 +667,7 @@ void MainWindow::fileSave() {
 }
 
 void MainWindow::fileSaveAs() {
-	KConfigGroup conf(KSharedConfig::openConfig(), "MainWindow");
+	KConfigGroup conf(KSharedConfig::openConfig(), QStringLiteral("MainWindow"));
 	QString dir = conf.readEntry("LastOpenDir", "");
 	QString fileName = QFileDialog::getSaveFileName(this, i18nc("@title:window", "Save As"), dir,
 	                   i18n("Portable game notation (*.pgn)"));
