@@ -55,7 +55,7 @@ KnightsView::~KnightsView() {
 	delete ui;
 }
 
-void KnightsView::drawBoard(KgThemeProvider* provider) {
+void KnightsView::drawBoard(KGameThemeProvider* provider) {
 	m_board = new Board(provider, this);
 	ui->canvas->setScene(m_board);
 	resizeScene();
@@ -66,7 +66,7 @@ void KnightsView::drawBoard(KgThemeProvider* provider) {
 	m_board->setPlayerColors(playerColors);
 }
 
-void KnightsView::setupBoard(KgThemeProvider* provider) {
+void KnightsView::setupBoard(KGameThemeProvider* provider) {
 	if (m_board)
 		delete m_board;
 
@@ -121,7 +121,7 @@ void KnightsView::showAllOffersToggled() {
 
 void KnightsView::popupHidden(int id) {
 	qCDebug(LOG_KNIGHTS) << m_offerWidgets << id << m_showAllOffers;
-	for (OfferWidget* widget : qAsConst(m_offerWidgets)) {
+	for (OfferWidget* widget : std::as_const(m_offerWidgets)) {
 		if ( widget->id() == id )
 			m_offerWidgets.removeAll(widget);
 	}
@@ -138,7 +138,7 @@ void KnightsView::updateOffers() {
 		return;
 	ui->showAllOffers->setIcon ( QIcon::fromTheme(QLatin1String( m_showAllOffers ? "arrow-up-double" : "arrow-down-double" )) );
 	ui->showAllOffers->setVisible ( m_offerWidgets.size() > 1 );
-	for (OfferWidget* widget : qAsConst(m_offerWidgets)) {
+	for (OfferWidget* widget : std::as_const(m_offerWidgets)) {
 		layout->removeWidget ( widget );
 		widget->hide();
 	}
